@@ -10,6 +10,8 @@
 extern "C" {
 #endif
 
+#define __SOUP_H_INSIDE__
+
 #include <libsoup/soup-address.h>
 #include <libsoup/soup-auth.h>
 #include <libsoup/soup-auth-domain.h>
@@ -37,6 +39,7 @@ extern "C" {
 #include <libsoup/soup-proxy-resolver-default.h>
 #include <libsoup/soup-proxy-uri-resolver.h>
 #include <libsoup/soup-request.h>
+#include <libsoup/soup-requester.h>
 #include <libsoup/soup-request-data.h>
 #include <libsoup/soup-request-file.h>
 #include <libsoup/soup-request-http.h>
@@ -55,6 +58,10 @@ extern "C" {
 #include <libsoup/soup-xmlrpc.h>
 #include <libsoup/soup-xmlrpc-old.h>
 
+#include <libsoup/soup-autocleanups.h>
+
+#undef __SOUP_H_INSIDE__
+
 #ifdef __cplusplus
 }
 #endif
