@@ -136,6 +136,14 @@ do_cookies_subdomain_policy_test (void)
 	g_assert_cmpint (g_slist_length (cookies), ==, 2);
 	g_slist_free_full (cookies, (GDestroyNotify)soup_cookie_free);
 
+	/* A leading dot in the domain property should not affect things.
+	 * This cookie should be accepted. Three cookies in the jar.
+	 */
+	soup_cookie_jar_set_cookie_with_first_party (jar, uri1, uri1, "4=foo; Domain=.www.gnome.org");
+	cookies = soup_cookie_jar_all_cookies (jar);
+	g_assert_cmpint (g_slist_length (cookies), ==, 3);
+	g_slist_free_full (cookies, (GDestroyNotify)soup_cookie_free);
+
 	soup_uri_free (uri1);
 	soup_uri_free (uri2);
 	g_object_unref (jar);
